/******************************************************************************
*******************************************************************************
*******************************************************************************
							Article Coding Project
							1980-2008
							Complexity by Method
							Figure 6
*******************************************************************************
*******************************************************************************
*******************************************************************************
******************************************************************************/

/****Calling and Cleaning the Data*****/

clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files" /*change*/
do "1980-2008 Initial Cleaning.do"

/**********The Goal: 
In Figure 6 we provide a series of box plots showing 
the relative use of concepts, issues, and both by data source 
of the article. Note that all cases of mixed data use are indexed under 
Mixed for this purpose, i.e., ANES indicates 
that the ANES was the only data source recorded for the survey, etc. 
 What is perhaps most notable about Figure 6 is the
 enhanced complexity of articles using solely survey data sources
 and particularly those focused exclusively on the ANES compared to
 those employing experimental methods"
 
 First, we will create the method indices
 *************/
 
 
 /*********methods*********/
egen method1 = anymatch(Q4_2_x*_1 /*all 48 concepts*/ ///
				Q8_2_x*_1  /*jobs*/ ///
				Q10_2_x*_1 /*blacks*/ ///
				Q12_2_x*_1 /*affirm action*/ ///
				Q14_2_x*_1 /*defense*/ ///
				Q16_2_x*_1 /*women*/ ///
				Q18_2_x*_1 /*abortion*/ ///
				Q20_2_x*_1 /*death penalty*/ ///
				Q22_2_x*_1 /*gay & lesbian*/ ///
				Q24_2_x*_1 /*environment*/ ///
				Q26_2_x*_1 /*spending*/ ///
				Q28_2_x*_1 /*internationalism*/), v(1)
	label var method1 "ANES"

	
egen method2 = anymatch(Q4_2_x*_2 /*all 48 concepts*/ ///
				Q8_2_x*_2  /*jobs*/ ///
				Q10_2_x*_2 /*blacks*/ ///
				Q12_2_x*_2 /*affirm action*/ ///
				Q14_2_x*_2 /*defense*/ ///
				Q16_2_x*_2 /*women*/ ///
				Q18_2_x*_2 /*abortion*/ ///
				Q20_2_x*_2 /*death penalty*/ ///
				Q22_2_x*_2 /*gay & lesbian*/ ///
				Q24_2_x*_2 /*environment*/ ///
				Q26_2_x*_2 /*spending*/ ///
				Q28_2_x*_2 /*internationalism*/), v(1)
	label var method2 "Other Survey"


egen method3 = anymatch(Q4_2_x*_3 /*all 48 concepts*/ ///
				Q8_2_x*_3  /*jobs*/ ///
				Q10_2_x*_3 /*blacks*/ ///
				Q12_2_x*_3 /*affirm action*/ ///
				Q14_2_x*_3 /*defense*/ ///
				Q16_2_x*_3 /*women*/ ///
				Q18_2_x*_3 /*abortion*/ ///
				Q20_2_x*_3 /*death penalty*/ ///
				Q22_2_x*_3 /*gay & lesbian*/ ///
				Q24_2_x*_3 /*environment*/ ///
				Q26_2_x*_3 /*spending*/ ///
				Q28_2_x*_3 /*internationalism*/), v(1)		
	label var method3 "Experiment" 


egen method4 = anymatch(Q4_2_x*_4 /*all 48 concepts*/ ///
				Q8_2_x*_4  /*jobs*/ ///
				Q10_2_x*_4 /*blacks*/ ///
				Q12_2_x*_4 /*affirm action*/ ///
				Q14_2_x*_4 /*defense*/ ///
				Q16_2_x*_4 /*women*/ ///
				Q18_2_x*_4 /*abortion*/ ///
				Q20_2_x*_4 /*death penalty*/ ///
				Q22_2_x*_4 /*gay & lesbian*/ ///
				Q24_2_x*_4 /*environment*/ ///
				Q26_2_x*_4 /*spending*/ ///
				Q28_2_x*_4 /*internationalism*/), v(1)		
	label var method4 "Archival"
	
tab1 method*
	/*
	ANES = 33.50% (392)
	Other Survey = 50.60 (592)
	Experiment = 9.66 (113)
	Archival = 16.07 (188)
	*/
	
	
gen method5 = 0
	replace method5 = 1 if method1 == 1 | method2 == 1
	label var method5 "Any Survey"
	tab method5
		/*78.03 (35)*/
	
	
gen method6 = 0
	replace method6 = 1 if method1 == 1 & method3 == 1
	label var method6 "ANES+Experiment"
	tab method6
	/*0.34 (4)*/
	
gen method7 = 0
	replace method7 = 1 if method5 == 1 & method3 == 1
	label var method7 "Survey+Experiment"
	tab method7
	/*2.14 (6)*/
	
	
/****
then, we'll create a variable for methodology in the paper. 
here we shunt *any* mixed data (i.e. ANES+SURVEY OR ANES+EXPERIMENT
to 'mixed'
******/
	
gen datatype = . 
	replace datatype = 1 if method1 == 1 & method2 == 0 & method3 == 0 & method4 == 0
	replace datatype = 2 if method1 == 0 & method2 == 1 & method3 == 0 & method4 == 0
	replace datatype = 3 if method1 == 0 & method2 == 0 & method3 == 1 & method4 == 0
	replace datatype = 4 if method1 == 0 & method2 == 0 & method3 == 0 & method4 == 1
	replace datatype = 5 if method1 == 1 & method2 == 1
	replace datatype = 5 if method1 == 1 & method3 == 1
	replace datatype = 5 if method1 == 1 & method4 == 1
	replace datatype = 5 if method2 == 1 & method3 == 1
	replace datatype = 5 if method2 == 1 & method4 == 1
	replace datatype = 5 if method3 == 1 & method4 == 1
label var datatype "Type of Data Source"
label def dtatype 1 "ANES" 2 "Other Survey" 3 "Experiment" 4 "Archival" 5 "Mixed"
label values datatype dtatype
	
	
/*****
now we'll create indicators for how mnay concepts, issues, 
or both appear in an article
******/

egen concepts = rowtotal(Q3_*) 
	label var concepts "Concepts"
	
egen issues = rowtotal(Q7_1_1 Q7_1_2 Q7_1_3 Q7_2_1 Q7_2_2 ///
	Q7_2_3 Q7_3_1 Q7_3_2 Q7_3_3 Q7_4_1 Q7_4_2 Q7_4_3 Q7_5_1 Q7_5_2 ///
	Q7_5_3 Q7_6_1 Q7_6_2 Q7_6_3 Q7_7_1 Q7_7_2 Q7_7_3 Q7_8_1 Q7_8_2 ///
	Q7_8_3 Q7_9_1 Q7_9_2 Q7_9_3 Q7_10_1 Q7_10_2 Q7_10_3 Q7_11_1 Q7_11_2 Q7_11_3) 
	label var issues "Issues"
	
egen total =  rowtotal(Q3_* Q7_1_1 Q7_1_2 Q7_1_3 Q7_2_1 Q7_2_2 ///
	Q7_2_3 Q7_3_1 Q7_3_2 Q7_3_3 Q7_4_1 Q7_4_2 Q7_4_3 Q7_5_1 Q7_5_2 ///
	Q7_5_3 Q7_6_1 Q7_6_2 Q7_6_3 Q7_7_1 Q7_7_2 Q7_7_3 Q7_8_1 Q7_8_2 ///
	Q7_8_3 Q7_9_1 Q7_9_2 Q7_9_3 Q7_10_1 Q7_10_2 Q7_10_3 Q7_11_1 Q7_11_2 Q7_11_3) 
	label var total "Total" 


/*****
now we create the box plots and
combine together
******/

foreach var in concepts issues total {
		graph box `var', over(datatype, label(angle(45) labsize(small))) scheme(s1mono) ///
			 ytitle("# Coded as Present") ///
			title("`: var label `var''", size(medlarge))
		graph save "box `var'", replace
		}
		
graph combine "box concepts" "box issues" "box total", scheme(s1mono) rows(1)

graph save "Figure 6", replace
graph export "Figure 6.png", replace
	
	
	
	
	
	
	
	
	
	
	
