
/******************************************************************************
*******************************************************************************
*******************************************************************************
							Article Coding Project
							1980-2008
							Most Used & Most Central & Data Use
							Table OA1: Concepts
							
*******************************************************************************
*******************************************************************************
*******************************************************************************
******************************************************************************/

/***********************************************
************************************************
	Concept Use Part 1
************************************************
***********************************************/



/****Calling and Cleaning the Data*****/

clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files" /**change**/
do "1980-2008 Initial Cleaning.do"

		
/*
To create the figures we want, we will reshape the data so that each row is
an article/concept pairing. We will then use the collapse function to 
create a new datset that that just focuses on the raw data that we want. 

To do this we will need to rename the concepts
and issues in a similar manner so that we can combine them. 
[If we wanted to treat them separately, we could skip this step.]
We will do this both for the appears/does not appear item and the
centra/not central item. 
*/

	/***Concepts****/
	
forval i = 1/48 {
	rename Q3_`i' topic`i'
	}

forval i = 1/48 {
	rename Q4_1_x`i' central`i'
	}




	/***Rehsaping****/

gen id = _n
	
reshape long topic central, i(id) j(top)
order topic central, after(top)


recode topic (0=.)
recode central (2 3=.) /***3???***/
	/*this makes the 'not central' missing data, which is 
	necessary for the 'count' code below*/

label def present 1 "Present" , replace
label def centr 1 "Central" , replace

label values topic present
label values central centr

tab1 topic central	

	
	
	
/***Topic Codes**/
label def topic_code ///
 1 "Difference btw Parties" 2 "Feel About Parties" 3 "PID" ///
 4 "Party Perf.: Economy" 5 "Party Perf: Foreign Affairs" /// 
 6 "Feelings abt President" 7 "Feelings abt Pres Candidates" ///
 8 "Feelings abt Congressional Candidates" 9 "Emotions abt Pres" 10 "Emotions abt Pres Cand" ///
 11 "Likes/Dislikes abt Pres Candidates" 12 "President's Traits" 13 "Presidential Candidate's Traits" ///
 14 "Approval President Job Performance" 15 "Approval President Performance Economy" ///
 16 "Approval President Performance Foreign Policy" 17 "Approval Congress Job Performance" ///
 18 "Approval of Congressional Rep's Job Performance" ///
 19 "Economic Performance" 20 "Personal Economic Situation" 21 "Position of Country in World Affairs" ///
 22 "Political Interest" 23 "Political Knowledge" 24 "Campaign Activity" ///
 25 "Campaing Contact" 26 "Vote Choice" 27 "Turnout in Nat'l  Elections" 28 "Registration" ///
 29 "Lib/Con Values" 30 "Religious Values/Beliefs" ///
 31 "Religious Identity" 32 "Moral Traditionalism" ///
 33 "Equalitarianism" 34 "Trust in Gov't" 35 "Political Efficacy" ///
 36 "TV News Consumption" 37 "Internet News Consumption" 38 "Newspaper Consumption" ///
 39 "Radio News  Consumption" 40 "Feelings abt Social Groups" ///
 41 "Attitudes abt Blacks" 42 "Stereotypes" 43 "Racial Identity" 44 "Ethnic Identity" ///
 45 "Social Class" 46 "Personality" 47 "Problems facing Country" 48 "Att. abt Divided Gov't" 

label values top topic_code



collapse (count) topic central, by(top)
list

gen id = _n
label var id "ID"

label var top "Concept"

gen percent = (topic/1163)*100
label var percent "Percent of Articles"

gen prop_central_use = (central/topic)*100
label var prop_central_use "Centrality Given Use (Central/Total)"

gen prop_central_all = central/1163
label var prop_central_all "Overall Centrality (Central/1163)"

format percent prop_central_use prop_central_all   %9.3g

keep top topic percent prop_central_use prop_central_all

save "Table OA1 - part1.dta", replace


/***********************************************
************************************************
	Data Use Part
************************************************
***********************************************/

/****Calling and Cleaning the Data*****/

clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files"
do "1980-2008 Initial Cleaning.do"

forval i = 1/48 {
	rename Q4_2_x`i'_1 	anes`i'
	rename Q4_2_x`i'_2 	survey`i'
	rename Q4_2_x`i'_3 	exp`i'
	rename Q4_2_x`i'_4 	arch`i'
	}

gen id = _n
reshape long anes survey exp arch, i(id) j(top)
order anes survey exp arch, first

recode anes survey exp arch (0=.)

collapse (count) anes survey exp arch, by(top)

label def topic_code ///
 1 "Difference btw Parties" 2 "Feel About Parties" 3 "PID" ///
 4 "Party Perf.: Economy" 5 "Party Perf: Foreign Affairs" /// 
 6 "Feelings abt President" 7 "Feelings abt Pres Candidates" ///
 8 "Feelings abt Congressional Candidates" 9 "Emotions abt Pres" 10 "Emotions abt Pres Cand" ///
 11 "Likes/Dislikes abt Pres Candidates" 12 "President's Traits" 13 "Presidential Candidate's Traits" ///
 14 "Approval President Job Performance" 15 "Approval President Performance Economy" ///
 16 "Approval President Performance Foreign Policy" 17 "Approval Congress Job Performance" ///
 18 "Approval of Congressional Rep's Job Performance" ///
 19 "Economic Performance" 20 "Personal Economic Situation" 21 "Position of Country in World Affairs" ///
 22 "Political Interest" 23 "Political Knowledge" 24 "Campaign Activity" ///
 25 "Campaing Contact" 26 "Vote Choice" 27 "Turnout in Nat'l  Elections" 28 "Registration" ///
 29 "Lib/Con Values" 30 "Religious Values/Beliefs" ///
 31 "Religious Identity" 32 "Moral Traditionalism" ///
 33 "Equalitarianism" 34 "Trust in Gov't" 35 "Political Efficacy" ///
 36 "TV News Consumption" 37 "Internet News Consumption" 38 "Newspaper Consumption" ///
 39 "Radio News  Consumption" 40 "Feelings abt Social Groups" ///
 41 "Attitudes abt Blacks" 42 "Stereotypes" 43 "Racial Identity" 44 "Ethnic Identity" ///
 45 "Social Class" 46 "Personality" 47 "Problems facing Country" 48 "Att. abt Divided Gov't" 

label values top topic_code

save "Table OA1 - part 2.dta", replace

/***********************************************
************************************************
	 Combining and Exporting
************************************************
***********************************************/

clear

use  "Table OA1 - part1.dta"
merge 1:1 top using "Table OA1 - part 2.dta"

drop _merge
gsort -topic

label var anes "ANES"
label var survey "Other Survey"
label var exp "Experiment"
label var arch "Archival"
label var topic "Total"

replace prop_central_all = prop_central_all*100

export excel using "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files\Table OA1.xls", 


